PrettyPrinter class

Default implementation of LogPrinter.

Output looks like this:

┌──────────────────────────
│ Error info
├┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄
│ Method stack history
├┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄
│ Log message
└──────────────────────────
Inheritance

Constructors

PrettyPrinter({int stackTraceBeginIndex = 0, int methodCount = 2, int errorMethodCount = 8, int lineLength = 120, bool colors = true, bool printEmojis = true, bool printTime = false, Map<Level, bool> excludeBox = const {}, bool noBoxingByDefault = false, List<String> excludePaths = const []})

Properties

colors → bool
Whether ansi colors are used to color the output.
final
errorMethodCount → int
Controls the method count in provided stack traces.
final
excludeBox → Map<Level, bool>
Controls the ascii 'boxing' of different Levels.
final
excludePaths → List<String>
A list of custom paths that are excluded from the stack trace.
final
hashCode → int
The hash code for this object.
no setterinherited
includeBox ↔ Map<Level, bool>
Contains the parsed rules resulting from excludeBox and noBoxingByDefault.
latefinal
lineLength → int
Controls the length of the divider lines.
final
methodCount → int
Controls the method count in created stack traces.
final
noBoxingByDefault → bool
Whether the implicit bools in excludeBox are true or false by default.
final
printEmojis → bool
Whether emojis are prefixed to the log line.
final
printTime → bool
Whether LogEvent.time is printed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTraceBeginIndex → int
The index at which the stack trace should start.
final

Methods

destroy() → void
inherited
formatStackTrace(StackTrace? stackTrace, int methodCount) → String?
getTime(DateTime time) → String
init() → void
inherited
log(LogEvent event) → List<String>
Is called every time a new LogEvent is sent and handles printing or storing the message.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stringifyMessage(dynamic message) → String
toEncodableFallback(dynamic object) → Object
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

levelColors → Map<Level, AnsiColor>
final
levelEmojis → Map<Level, String>
final

Constants

bottomLeftCorner → const String
doubleDivider → const String
middleCorner → const String
singleDivider → const String
topLeftCorner → const String
verticalLine → const String